@@ -330,6 +330,7 @@ async def apply_namespace(
     help="Tenta reescrever em caso de falha",
 )
 @click.option("--w", default="majority", help="Nível de escrita do MongoDB")
+@click.option("--mongo-url", help="URL do MongoDB")
 def apply_command(
     metadata_dir: str,
     host: str,
@@ -344,6 +345,7 @@ def apply_command(
     direct_connection: bool,
     retry_writes: bool,
     w: str,
+    mongo_url: Optional[str],
 ) -> None:
     """Aplica alterações locais ao MongoDB."""
     asyncio.run(
@@ -361,6 +363,7 @@ def apply_command(
             direct_connection=direct_connection,
             retry_writes=retry_writes,
             w=w,
+            mongo_url=mongo_url,
         )
     )
 
@@ -379,6 +382,7 @@ async def _apply_command(
     direct_connection: bool,
     retry_writes: bool,
     w: str,
+    mongo_url: Optional[str],
 ) -> None:
     """Internal async implementation of apply command."""
     metadata_path = Path(metadata_dir).resolve()
@@ -386,23 +390,26 @@ async def _apply_command(
         console.print(f"[red]Diretório {metadata_dir} não encontrado[/red]")
         return
 
-    uri_params = []
-    if replicaset:
-        uri_params.extend(
-            [
-                f"replicaSet={replicaset}",
-                f"directConnection={'true' if direct_connection else 'false'}",
-                f"retryWrites={'true' if retry_writes else 'false'}",
-                f"w={w}",
-            ]
-        )
+    uri = mongo_url
 
-    uri_suffix = f"?{'&'.join(uri_params)}" if uri_params else ""
+    if not uri:
+        uri_params = []
+        if replicaset:
+            uri_params.extend(
+                [
+                    f"replicaSet={replicaset}",
+                    f"directConnection={'true' if direct_connection else 'false'}",
+                    f"retryWrites={'true' if retry_writes else 'false'}",
+                    f"w={w}",
+                ]
+            )
 
-    if username and password:
-        uri = f"mongodb://{username}:{password}@{host}:{port}/admin{uri_suffix}"
-    else:
-        uri = f"mongodb://{host}:{port}{uri_suffix}"
+        uri_suffix = f"?{'&'.join(uri_params)}" if uri_params else ""
+
+        if username and password:
+            uri = f"mongodb://{username}:{password}@{host}:{port}/admin{uri_suffix}"
+        else:
+            uri = f"mongodb://{host}:{port}{uri_suffix}"
 
     client = MongoClient(
         uri,
@@ -541,3 +548,5 @@ if __name__ == "__main__":
     main()
     main()
     main()
+    main()
+    main()
